summaryrefslogtreecommitdiffstats
path: root/amarok/src/magnatunebrowser/magnatunepurchasehandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'amarok/src/magnatunebrowser/magnatunepurchasehandler.h')
-rw-r--r--amarok/src/magnatunebrowser/magnatunepurchasehandler.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/amarok/src/magnatunebrowser/magnatunepurchasehandler.h b/amarok/src/magnatunebrowser/magnatunepurchasehandler.h
index 9889c66f..a9a5e538 100644
--- a/amarok/src/magnatunebrowser/magnatunepurchasehandler.h
+++ b/amarok/src/magnatunebrowser/magnatunepurchasehandler.h
@@ -35,14 +35,15 @@ The main class responcible for handelig of purchases from Magnatune.com
@author Nikolaj Hald Nielsen
*/
-class MagnatunePurchaseHandler : public QObject
+class MagnatunePurchaseHandler : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
MagnatunePurchaseHandler();
~MagnatunePurchaseHandler();
- void setParent( TQWidget * parent );
+ void setParent( TQWidget * tqparent );
/**
* Starts a purchase operation
* @param album The album to purchase
@@ -57,8 +58,8 @@ private:
KIO::TransferJob * m_resultDownloadJob;
- //need a parent to pass to any dialogs we spawn
- TQWidget * m_parent;
+ //need a tqparent to pass to any dialogs we spawn
+ TQWidget * m_tqparent;
MagnatunePurchaseDialog * m_purchaseDialog;
MagnatuneDownloadDialog * m_downloadDialog;
MagnatuneAlbumDownloader * m_albumDownloader;